/* utility styles - used generally in posts and pages - FIXME move to a different page */

/* info boxes */
.information {
	display: block;
	padding: 1em;
	border: 1px dashed #adade3;
	-moz-border-radius: 2mm;
	margin: 1em 0em 1em 0em;
}

.information > *:first-child {
	margin-top: 0px;
	padding-top: 0px;
}

.information > *:last-child {
	margin-bottom: 0px;
	padding-bottom: 0px;
}

/* float controls */

.floatright {
	float: right;
	text-align: right;
}

.floatleft {
	float:left;
}

/* thumbnail lists they get aligned vertically */
.centered {
	vertical-align: center;
	text-align: center;
}

/* side inset */
.inset {
	display: block;
	width: 40%;
	color: #616193;
	padding-left: 1em;
	padding-right: 1em;
	padding-top: 1em;
	padding-bottom: 1em;
	border: 1px dashed #adade3;
	-moz-border-radius: 2mm;
	margin-top: 0.3em;
	margin-bottom: 0.3em;
}

.inset > *:first-child {
	margin-top: 0px;
	padding-top: 0px;
}

.inset > *:last-child {
	margin-bottom: 0px;
	padding-bottom: 0px;
}


/* thumbnail look */
.thumbnail {
	border: none;
	padding: 4px;
}

/* insets and thumbnails have their margins so they don't get mixed up with the text */

.inset.floatright , .thumbnail.floatright {
	margin-left: 0.5em;
	margin-right: 0em;
}

.inset.floatleft, .thumbnail.floatleft  {
	margin-left: 0em;
	margin-right: 0.5em;
}

/* something we can use to force any element to go down anything that floats */

.clearbothsides {
	clear: both;
}

/* end utility styles */
