<script type="text/javascript"><!--
google_ad_client = "pub-0872790598670514";
google_ad_width = 180;
google_ad_height = 60;
google_ad_format = "180x60_as_rimg";
google_cpa_choice = "CAAQ56j8zwEaCHvU9tBAqJJaKMu293M";
//--></script>
<script type="text/javascript" src="http://pagead2.googlesyndication.com/pagead/show_ads.js">
</script>
