<!-- Creative Commons License -->
<a title="Except where expressly acknowledged, this work is licensed under a Creative Commons License" rel="license" 
href="http://creativecommons.org/licenses/by-nc-sa/2.0/"><img 
alt="Except where expressly 
acknowledged, this work is licensed under a Creative Commons License" border="0" 
src="<?php bloginfo('template_directory'); ?>/images/somerights20.gif" /></a>
<!-- /Creative Commons License -->


<!--

<rdf:RDF xmlns="http://web.resource.org/cc/"
    xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
<Work rdf:about="">
   <dc:title>The Rudd&amp;#45;O's zone</dc:title>
   <dc:date>1999</dc:date>
   <dc:description>My blog's original content</dc:description>
   <dc:creator><Agent>
      <dc:title>Rudd&amp;#45;O</dc:title>
   </Agent></dc:creator>
   <dc:rights><Agent>
      <dc:title>Rudd&amp;#45;O</dc:title>
   </Agent></dc:rights>
   <dc:type rdf:resource="http://purl.org/dc/dcmitype/Text" />
   <dc:source rdf:resource="http://www.amautacorp.com/staff/Rudd&amp;#45;O/"/>
   <license rdf:resource="http://creativecommons.org/licenses/by-nc-sa/2.0/" />
</Work>

<License rdf:about="http://creativecommons.org/licenses/by-nc-sa/2.0/">
   <permits rdf:resource="http://web.resource.org/cc/Reproduction" />
   <permits rdf:resource="http://web.resource.org/cc/Distribution" />
   <requires rdf:resource="http://web.resource.org/cc/Notice" />
   <requires rdf:resource="http://web.resource.org/cc/Attribution" />
   <prohibits rdf:resource="http://web.resource.org/cc/CommercialUse" />
   <permits rdf:resource="http://web.resource.org/cc/DerivativeWorks" />
   <requires rdf:resource="http://web.resource.org/cc/ShareAlike" />
</License>

</rdf:RDF>

-->

