
<!-- this should go in the footer -->


<div id="footer">

	<p id="pageprintoutinfo">
	This page is a printout of part of <?php bloginfo('name'); ?>.<br/>
	<?php 
	$myuri = $_SERVER['REQUEST_URI'];
	$myhost = $_SERVER['SERVER_NAME'];
	?>
	
	URL of this printout: <a href="<?php echo $myuri ?>">http://<?php echo $myhost . $myuri ?></a>
	</p>

        <div id="sponsored-links-wide-bottom">
                <?php include(TEMPLATEPATH . "/adwide.php"); ?>
        </div>

	<p>
		<?php bloginfo('name'); ?> uses the 
		<a href="http://wordpress.org">WordPress</a> personal publishing platform.
		<br/>
		<?php if (function_exists("validator_campaign_long")) {
    			validator_campaign_long(); print "<br/>"; }?>
		This Web site may require a highly standards compliant Web browser.
		<br/>
		Tested on <a href="http://mozilla.org">Mozilla, Firefox</a>, <a href="http://kde.org">Konqueror</a>, Microsoft Internet Explorer 7
		<br />
		Subscribe to this site's <a href="feed:<?php bloginfo('rss2_url'); ?>">Entries (RSS)</a>
		or <a href="feed:<?php bloginfo('comments_rss2_url'); ?>">Comments (RSS)</a>.
		<!-- <?php echo $wpdb->num_queries; ?> queries. <?php timer_stop(1); ?> seconds. -->
	</p>
</div>
</div>

<?php /* "Just what do you think you're doing Dave?" */ ?>

		<?php wp_footer(); ?>

<script language="JavaScript" type="text/javascript" src="<?php bloginfo('template_directory'); ?>/library.js"></script>
</body>
</html>
