<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">

<head profile="http://gmpg.org/xfn/11">
<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php bloginfo('charset'); ?>" />

<title><?php
	function dd() {
		global $httperrortitle;
		if (isset($httperrortitle)) echo " " . $httperrortitle . " &raquo;  ";
		elseif ($_GET['showpage'] == 'archives') { ?> Complete archives &raquo; <?php }
		elseif ($_GET['showpage'] == 'directoryindex') { ?> Folder contents &raquo; <?php }
 		elseif ( is_single() ) { ?><?php /* do not put anything, leave empty to increase SEO relevance  */ }
	}
	if (function_exists("optimal_title")) { optimal_title(); dd(); bloginfo('name'); }
	else { bloginfo('name'); dd(); wp_title(); }
	?></title>

<meta name="generator" content="WordPress <?php bloginfo('version'); ?>" /> <!-- leave this for stats -->

<style type="text/css">@import url(<?php bloginfo('stylesheet_url'); ?>);</style>

<link rel="alternate" type="application/rss+xml" title="<?php bloginfo('name'); ?> (using RSS 2.0)" href="<?php bloginfo('rss2_url'); ?>" />
<link rel="alternate" type="text/xml" title="<?php bloginfo('name'); ?> (using RSS .92)" href="<?php bloginfo('rss_url'); ?>" />
<link rel="alternate" type="application/atom+xml" title="<?php bloginfo('name'); ?> (using Atom 0.3)" href="<?php bloginfo('atom_url'); ?>" />
<link rel="pingback" href="<?php bloginfo('pingback_url'); ?>" />
<link rel="shortcut icon" href="<?php bloginfo('template_directory'); ?>/images/favicon.ico"/>

<?php wp_head(); ?>

<?php comments_popup_script(450, 450); ?>

<?php wp_get_archives('type=monthly&format=link'); ?>

</head>

<body class="themed RevvedUp">

<div id="page">

<div id="header">
	<div id="headerimg">
		<h1><a href="<?php echo get_settings('home'); ?>"><?php bloginfo('name'); ?></a></h1>
		<div class="description"><?php bloginfo('description'); ?></div>
	</div>
</div>
